/**
 * Generatea random sequence number.
 *
 * @returns {Uint8Array}
 * @private
 */
export function randomSeqno(): Uint8Array;
/**
 * Generate a message id, based on the `from` and `seqno`.
 *
 * @param {string} from
 * @param {Uint8Array} seqno
 * @returns {Uint8Array}
 * @private
 */
export function msgId(from: string, seqno: Uint8Array): Uint8Array;
/**
 * Generate a message id, based on message `data`.
 *
 * @param {Uint8Array} data
 * @returns {Uint8Array}
 * @private
 */
export function noSignMsgId(data: Uint8Array): Uint8Array;
/**
 * Check if any member of the first set is also a member
 * of the second set.
 *
 * @param {Set<number>|Array<number>} a
 * @param {Set<number>|Array<number>} b
 * @returns {boolean}
 * @private
 */
export function anyMatch(a: Set<number> | Array<number>, b: Set<number> | Array<number>): boolean;
/**
 * Make everything an array.
 *
 * @template T
 * @param {T|T[]} maybeArray
 * @returns {T[]}
 * @private
 */
export function ensureArray<T>(maybeArray: T | T[]): T[];
/**
 * Ensures `message.from` is base58 encoded
 *
 * @template {{from?:any}} T
 * @param {T & {from?:string, receivedFrom:string}} message
 * @param {string} [peerId]
 * @returns {T & {from?: string, peerId?: string }}
 */
export function normalizeInRpcMessage<T extends {
    from?: any;
}>(message: T & {
    from?: string | undefined;
    receivedFrom: string;
}, peerId?: string | undefined): T & {
    from?: string | undefined;
    peerId?: string | undefined;
};
/**
 * @template {{from?:any, data?:any}} T
 *
 * @param {T} message
 * @returns {T & {from?: Uint8Array, data?: Uint8Array}}
 */
export function normalizeOutRpcMessage<T extends {
    from?: any;
    data?: any;
}>(message: T): T & {
    from?: Uint8Array | undefined;
    data?: Uint8Array | undefined;
};
//# sourceMappingURL=utils.d.ts.map